//##############################################################################
//
// FILE:   usb_hal.c
//
// TITLE:  Wrapper for interrupt functions and USB support pins.
//
//##############################################################################
// $TI Release: $
// $Release Date: $
// $Copyright: $
//##############################################################################

//
// Include Files.
//
#include "usb_hal.h"

//******************************************************************************
//
//! \addtogroup c2000_specific
//! @{
//
//******************************************************************************
//******************************************************************************
//
//! Enables USB related GPIOs to perform their USB function.
//
//******************************************************************************
void USBGPIOEnable(void)
{
    //
    // Set the USB DM and DP.
    //
    GPIO_setMasterCore(42, GPIO_CORE_CPU1);
    GPIO_setAnalogMode(42, GPIO_ANALOG_ENABLED);
    GPIO_setMasterCore(43, GPIO_CORE_CPU1);
    GPIO_setAnalogMode(43, GPIO_ANALOG_ENABLED);

    //
    // Set the direction for VBUS.
    //
    GPIO_setMasterCore(46, GPIO_CORE_CPU1);
    GPIO_setDirectionMode(46, GPIO_DIR_MODE_IN);

    //
    // Set the direction for ID.
    //
    GPIO_setMasterCore(47, GPIO_CORE_CPU1);
    GPIO_setDirectionMode(47, GPIO_DIR_MODE_IN);

    GPIO_setMasterCore(120, GPIO_CORE_CPU1);
    GPIO_setPinConfig(GPIO_120_USB0PFLT);

    GPIO_setMasterCore(121, GPIO_CORE_CPU1);
    GPIO_setPinConfig(GPIO_121_USB0EPEN);
}

//******************************************************************************
//
//! Configure the CPU Timer.
//
//******************************************************************************
void CPUTimerInit(void)
{
    //
    // Initialize timer period to maximum.
    //
    CPUTimer_setPeriod(CPUTIMER0_BASE,0xFFFFFFFF);

    //
    // Initialize Pre-scale counter to divide by 1.
    //
    CPUTimer_setPreScaler(CPUTIMER0_BASE, 0U);

    //
    // Make sure timer is stopped.
    //
    CPUTimer_stopTimer(CPUTIMER0_BASE);

    //
    // Reload all counter register with period value:
    //
    CPUTimer_reloadTimerCounter(CPUTIMER0_BASE);
}
//******************************************************************************
//
//! Wrapper function to implement mS based delay for USB functions
//
//******************************************************************************
void USBDelay(uint32_t ui32Delay)
{
    DEVICE_DELAY_US(ui32Delay*1000);
}

//******************************************************************************
//
//! Device interrupt service routine wrapper to make ISR compatible with
//! C2000 PIE controller.
//
//******************************************************************************
__interrupt void
f28x_USB0DeviceIntHandler(void)
{
    USB0DeviceIntHandler();
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
}

//******************************************************************************
//
//! Host interrupt service routine wrapper to make ISR compatible with
//! C2000 PIE controller.
//
//******************************************************************************
__interrupt void
f28x_USB0HostIntHandler(void)
{
    USB0HostIntHandler();
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
}

//******************************************************************************
//
//! Dual mode interrupt service routine wrapper to make ISR compatible with
//! C2000 PIE controller.
//
//******************************************************************************
__interrupt void
f28x_USB0DualModeIntHandler(void)
{
    USB0DualModeIntHandler();
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
}

//******************************************************************************
//
//! Dual mode interrupt service routine wrapper to make ISR compatible with
//! C2000 PIE controller.
//
//******************************************************************************
__interrupt void
f28x_USB0OTGModeIntHandler(void)
{
    USB0OTGModeIntHandler();
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
}

//******************************************************************************
//
// Close the c2000_specific Doxygen group.
//! @}
//
//******************************************************************************
